summaryrefslogtreecommitdiff
path: root/common/src/txe_queue_create.c
diff options
context:
space:
mode:
authorFrédéric Desbiens <[email protected]>2026-04-15 11:36:53 -0400
committerGitHub <[email protected]>2026-04-15 11:36:53 -0400
commitf81d1c9eb5a0bc16ba26426e5274f7248a7c8646 (patch)
treea036816ab14c9e6d97e44486ecbd571d7f925d32 /common/src/txe_queue_create.c
parente755542cb3be2cb9510630748712bb5cb6e58ffb (diff)
parent454ab56fcecb35c0b24dc2f0bed6b8551a797fac (diff)
Merge branch 'dev' into typo
Diffstat (limited to 'common/src/txe_queue_create.c')
-rw-r--r--common/src/txe_queue_create.c19
1 files changed, 6 insertions, 13 deletions
diff --git a/common/src/txe_queue_create.c b/common/src/txe_queue_create.c
index 68d3540a..185289fe 100644
--- a/common/src/txe_queue_create.c
+++ b/common/src/txe_queue_create.c
@@ -1,10 +1,11 @@
/***************************************************************************
- * Copyright (c) 2024 Microsoft Corporation
- *
+ * Copyright (c) 2024 Microsoft Corporation
+ * Copyright (c) 2026-present Eclipse ThreadX contributors
+ *
* This program and the accompanying materials are made available under the
* terms of the MIT License which is available at
* https://opensource.org/licenses/MIT.
- *
+ *
* SPDX-License-Identifier: MIT
**************************************************************************/
@@ -70,14 +71,6 @@
/* */
/* Application Code */
/* */
-/* RELEASE HISTORY */
-/* */
-/* DATE NAME DESCRIPTION */
-/* */
-/* 05-19-2020 William E. Lamie Initial Version 6.0 */
-/* 09-30-2020 Yuxin Zhou Modified comment(s), */
-/* resulting in version 6.1 */
-/* */
/**************************************************************************/
UINT _txe_queue_create(TX_QUEUE *queue_ptr, CHAR *name_ptr, UINT message_size,
VOID *queue_start, ULONG queue_size, UINT queue_control_block_size)
@@ -178,8 +171,8 @@ TX_THREAD *thread_ptr;
status = TX_SIZE_ERROR;
}
- /* Check for an invalid message size - greater than 16. */
- else if (message_size > TX_16_ULONG)
+ /* Check for an invalid message size - greater than TX_QUEUE_MESSAGE_MAX_SIZE 16 by default. */
+ else if (message_size > TX_QUEUE_MESSAGE_MAX_SIZE)
{
/* Invalid message size specified. */